.. _model-fields:

============
Model Fields
============


More MySQL and MariaDB specific ways to store data!

Field classes should always be imported from ``django_mysql.models``, similar
to the home of Django's native fields in ``django.db.models``.

.. toctree::
   :maxdepth: 1

   json_field
   dynamic_field
   list_fields
   set_fields
   enum_field
   resizable_text_binary_fields
   null_bit1_boolean_fields

.. currentmodule:: django_mysql.models
